<?php

namespace Litepie\Member\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Member\Interfaces\MembershipRepositoryInterface;

class MembershipPublicController extends BaseController
{
    // use MembershipWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Membership\Interfaces\MembershipRepositoryInterface $membership
     *
     * @return type
     */
    public function __construct(MembershipRepositoryInterface $membership)
    {
        $this->repository = $membership;
        parent::__construct();
    }

    /**
     * Show membership's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $memberships = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('member::membership.names'))
            ->view('member::public.membership.index')
            ->data(compact('memberships'))
            ->output();
    }


    /**
     * Show membership.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $membership = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($membership->name . trans('member::membership.name'))
            ->view('member::public.membership.show')
            ->data(compact('membership'))
            ->output();
    }

}
