<?php

namespace Litepie\Member\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Member\Interfaces\TypeRepositoryInterface;

class TypePublicController extends BaseController
{
    // use TypeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Type\Interfaces\TypeRepositoryInterface $type
     *
     * @return type
     */
    public function __construct(TypeRepositoryInterface $type)
    {
        $this->repository = $type;
        parent::__construct();
    }

    /**
     * Show type's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $types = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('member::type.names'))
            ->view('member::public.type.index')
            ->data(compact('types'))
            ->output();
    }


    /**
     * Show type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $type = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($type->name . trans('member::type.name'))
            ->view('member::public.type.show')
            ->data(compact('type'))
            ->output();
    }

}
