<?php

namespace Litepie\Member\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Member\Models\Member;

class MemberPolicy
{

    /**
     * Determine if the given user can view the member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function view(UserPolicy $user, Member $member)
    {
        if ($user->canDo('member.member.view') && $user->isAdmin()) {
            return true;
        }

        return $member->user_id == user_id() && $member->user_type == user_type();
    }

    /**
     * Determine if the given user can create a member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('member.member.create');
    }

    /**
     * Determine if the given user can update the given member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function update(UserPolicy $user, Member $member)
    {
        if ($user->canDo('member.member.edit') && $user->isAdmin()) {
            return true;
        }

        return $member->user_id == user_id() && $member->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Member $member)
    {
        return $member->user_id == user_id() && $member->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Member $member)
    {
        if ($user->canDo('member.member.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given member.
     *
     * @param UserPolicy $user
     * @param Member $member
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Member $member)
    {
        if ($user->canDo('member.member.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
