<?php

namespace Litepie\Member\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Member\Models\Membership;

class MembershipPolicy
{

    /**
     * Determine if the given user can view the membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function view(UserPolicy $user, Membership $membership)
    {
        if ($user->canDo('member.membership.view') && $user->isAdmin()) {
            return true;
        }

        return $membership->user_id == user_id() && $membership->user_type == user_type();
    }

    /**
     * Determine if the given user can create a membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('member.membership.create');
    }

    /**
     * Determine if the given user can update the given membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function update(UserPolicy $user, Membership $membership)
    {
        if ($user->canDo('member.membership.edit') && $user->isAdmin()) {
            return true;
        }

        return $membership->user_id == user_id() && $membership->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Membership $membership)
    {
        return $membership->user_id == user_id() && $membership->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Membership $membership)
    {
        if ($user->canDo('member.membership.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given membership.
     *
     * @param UserPolicy $user
     * @param Membership $membership
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Membership $membership)
    {
        if ($user->canDo('member.membership.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
