<?php

namespace Litepie\Member\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Member\Models\Member;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Member\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/member/member/*')) {
            Route::bind('member', function ($member) {
                $memberrepo = $this->app->make('Litepie\Member\Interfaces\MemberRepositoryInterface');
                return $memberrepo->findorNew($member);
            });
        }

        if (Request::is('*/member/type/*')) {
            Route::bind('type', function ($type) {
                $typerepo = $this->app->make('Litepie\Member\Interfaces\TypeRepositoryInterface');
                return $typerepo->findorNew($type);
            });
        }

        if (Request::is('*/member/membership/*')) {
            Route::bind('membership', function ($membership) {
                $membershiprepo = $this->app->make('Litepie\Member\Interfaces\MembershipRepositoryInterface');
                return $membershiprepo->findorNew($membership);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
